@@ -6,7 +6,7 @@ import numpy as np
 import datetime
 from geopy.geocoders import Nominatim
 from datetime import timedelta
-
+import time
 
 def earthquake_distance(place):    
 
@@ -39,7 +39,7 @@ def earthquake_distance(place):
     
     
 
-    json_url = urlopen('https://earthquake.usgs.gov/fdsnws/event/1/query?format=geojson&starttime='+ str(today) +'&endtime=' + str(yesterday))
+    json_url = urlopen('https://earthquake.usgs.gov/fdsnws/event/1/query?format=geojson&starttime='+ str(yesterday) +'&endtime=' + str(today))
     data = json.loads(json_url.read())
 
     json_dict = data.get('features')
@@ -127,7 +127,7 @@ def earthquake_longitude(place):
 
 
 
-    json_url = urlopen('https://earthquake.usgs.gov/fdsnws/event/1/query?format=geojson&starttime='+ str(today) +'&endtime=' + str(yesterday))
+    json_url = urlopen('https://earthquake.usgs.gov/fdsnws/event/1/query?format=geojson&starttime='+ str(yesterday) +'&endtime=' + str(today))
     data = json.loads(json_url.read())
 
     json_dict = data.get('features')
@@ -215,7 +215,7 @@ def earthquake_latitude(place):
 
     
 
-    json_url = urlopen('https://earthquake.usgs.gov/fdsnws/event/1/query?format=geojson&starttime='+ str(today) +'&endtime=' + str(yesterday))
+    json_url = urlopen('https://earthquake.usgs.gov/fdsnws/event/1/query?format=geojson&starttime='+ str(yesterday) +'&endtime=' + str(today))
     data = json.loads(json_url.read())
 
     json_dict = data.get('features')
@@ -303,7 +303,7 @@ def earthquake_magnitude(place):
 
     
 
-    json_url = urlopen('https://earthquake.usgs.gov/fdsnws/event/1/query?format=geojson&starttime='+ str(today) +'&endtime=' + str(yesterday))
+    json_url = urlopen('https://earthquake.usgs.gov/fdsnws/event/1/query?format=geojson&starttime='+ str(yesterday) +'&endtime=' + str(today))
     data = json.loads(json_url.read())
 
     json_dict = data.get('features')
@@ -390,7 +390,7 @@ def earthquake_place(place):
 
     
 
-    json_url = urlopen('https://earthquake.usgs.gov/fdsnws/event/1/query?format=geojson&starttime='+ str(today) +'&endtime=' + str(yesterday))
+    json_url = urlopen('https://earthquake.usgs.gov/fdsnws/event/1/query?format=geojson&starttime='+ str(yesterday) +'&endtime=' + str(today))
     data = json.loads(json_url.read())
 
     json_dict = data.get('features')
@@ -449,7 +449,8 @@ def earthquake_place(place):
 
 
 
-def earthquake_time(place):    
+def earthquake_time(place):
+
 
 
     #https://towardsdatascience.com/heres-how-to-calculate-distance-between-2-geolocations-in-python-93ecab5bbba4
@@ -478,7 +479,7 @@ def earthquake_time(place):
 
     
 
-    json_url = urlopen('https://earthquake.usgs.gov/fdsnws/event/1/query?format=geojson&starttime='+ str(today) +'&endtime=' + str(yesterday))
+    json_url = urlopen('https://earthquake.usgs.gov/fdsnws/event/1/query?format=geojson&starttime='+ str(yesterday) +'&endtime=' + str(today))
     data = json.loads(json_url.read())
 
     json_dict = data.get('features')
@@ -532,8 +533,12 @@ def earthquake_time(place):
     place_v = all["place"].iloc[0]
     time_v = all["time"].iloc[0]
     # can also return df as dataframe
+
+
+    timestamp = time_v
+    dt_obj = datetime.fromtimestamp(timestamp / 1000).strftime('%d-%m-%y')
     
-    return time_v
+    return dt_obj
 
 def earthquake_df(place):    
 
@@ -564,7 +569,7 @@ def earthquake_df(place):
 
     
 
-    json_url = urlopen('https://earthquake.usgs.gov/fdsnws/event/1/query?format=geojson&starttime='+ str(today) +'&endtime=' + str(yesterday))
+    json_url = urlopen('https://earthquake.usgs.gov/fdsnws/event/1/query?format=geojson&starttime='+ str(yesterday) +'&endtime=' + str(today))
     data = json.loads(json_url.read())
 
     json_dict = data.get('features')
